/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
  clock.h: Clock and timefunctions for Gnome Predict.

  Copyright (C)  2001-2005  Alexandru Csete.

  Authors:  Alexandru Csete <csete@users.sourceforge.net>

  Comments, questions and bugreports should be submitted via
  http://sourceforge.net/projects/groundstation/
  More details can be found at http://groundstation.sourceforge.net/
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the
          Free Software Foundation, Inc.,
	  59 Temple Place, Suite 330,
	  Boston, MA  02111-1307
	  USA
*/

#ifndef CLOCK_H
#define CLOCK_H

#define CLOCK_SHOW_LOCAL_TIME_PATH "/apps/gpredict/showlocaltime"
#define CLOCK_TIME_FORMAT_PATH     "/apps/gpredict/timeformat"
#define CLOCK_TIME_FORMAT_DEFAULT  "%c"  /* local date and time representation */

gint clock_timer_callback (gpointer);
void clock_timer_start    (void);
void clock_timer_stop     (void);

#endif
